==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/fa/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "زبانه جدید",
  "default_label_loading": "در حال بارگیری…",
  "header_top_sites": "سایت‌های برتر",
  "header_stories": "برترین داستان‌ها",
  "header_highlights": "برجسته‌ها",
  "header_visit_again": "مشاهده دوباره",
  "header_bookmarks": "نشانک‌های اخیر",
  "header_recommended_by": "پیشنهاد شده توسط {provider}",
  "header_bookmarks_placeholder": "هنوز هیچ نشانکی ندارید.",
  "header_stories_from": "از",
  "type_label_visited": "مشاهده شده",
  "type_label_bookmarked": "نشانک شده",
  "type_label_synced": "هم‌گام شده از دستگاهی دیگر",
  "type_label_recommended": "موضوعات داغ",
  "type_label_open": "باز کردن",
  "type_label_topic": "موضوع",
  "type_label_now": "هم‌اکنون",
  "menu_action_bookmark": "نشانک",
  "menu_action_remove_bookmark": "حذف نشانک",
  "menu_action_copy_address": "رونوشت از آدرس",
  "menu_action_email_link": "ارسال پیوند…",
  "menu_action_open_new_window": "باز کردن در یک پنجره جدید",
  "menu_action_open_private_window": "بار کردن در یک پنجره ناشناس جدید",
  "menu_action_dismiss": "رد کردن",
  "menu_action_delete": "حذف از تاریخچه",
  "menu_action_pin": "سنجاق کردن",
  "menu_action_unpin": "جدا کردن",
  "confirm_history_delete_p1": "آیا از پاک کردن همه نمونه‌های این صفحه از تاریخ‌چه خود اطمینان دارید؟",
  "confirm_history_delete_notice_p2": "این عمل قابل برگشت نیست.",
  "menu_action_save_to_pocket": "ذخیره‌سازی در Pocket",
  "search_for_something_with": "جست‌وجو برای {search_term} با:",
  "search_button": "جست‌وجو",
  "search_header": "جست‌وجو {search_engine_name}",
  "search_web_placeholder": "جست‌وجوی وب",
  "search_settings": "تغییر تنظیمات جست‌وجو",
  "section_info_option": "اطلاعات",
  "section_info_send_feedback": "ارسال بازخورد",
  "section_info_privacy_notice": "نکات حفظ حریم خصوصی",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "به زبانه جدید خوش‌آمدید",
  "welcome_body": "فایرفاکس از این فضا برای نمایش نشانک‌ها، مقالات، ویدئوها و صفحات مرتبطی که به‌تازگی مشاهده کرده‌اید استفاده می‌کند، تا شما به راحتی دوباره به آنها دسترسی داشته باشید.",
  "welcome_label": "شناسایی گزینه‌های برجسته شما",
  "time_label_less_than_minute": "> ۱ دقیقه",
  "time_label_minute": "{number} د",
  "time_label_hour": "{number} س",
  "time_label_day": "{number} ر",
  "settings_pane_button_label": "صفحهٔ زبانه جدید را سفارشی کنید",
  "settings_pane_header": "تنظیمات زبانه جدید",
  "settings_pane_body2": "انتخاب کنید چیزی را که مایل هستید در این صفحه مشاهده کنید.",
  "settings_pane_search_header": "جست‌وجو",
  "settings_pane_search_body": "وب را از زبانه جدید خود جست‌وجو کنید.",
  "settings_pane_topsites_header": "سایت‌های برتر",
  "settings_pane_topsites_body": "به وب‌سایت‌هایی که بیشترین بازدید از آنها را داشتید دسترسی داشته باشید.",
  "settings_pane_topsites_options_showmore": "نمایش دو ردیفی",
  "settings_pane_bookmarks_header": "نشانک‌های اخیر",
  "settings_pane_bookmarks_body": "به‌تازگی شما نشانک‌هایی را در یک محل مناسب ساخته‌اید.",
  "settings_pane_visit_again_header": "مشاهده دوباره",
  "settings_pane_visit_again_body": "فایرفاکس بخش‌هایی از تاریخ‌چه مرورتان را که ممکن است بخواهید به یاد داشته باشید یا به آن‌ها بازگردید به شما نشان خواهد داد.",
  "settings_pane_highlights_header": "برجسته‌ها",
  "settings_pane_highlights_body2": "راه خود را در میان چیزهایی که دوست دارید پیدا کنید.چیزهایی که اخیرا مشاهده کرده اید یا نشانک ها.",
  "settings_pane_highlights_options_bookmarks": "نشانک‌ها",
  "settings_pane_highlights_options_visited": "سایت‌های بازدید شده",
  "settings_pane_snippets_header": "قطعه‌ها",
  "settings_pane_snippets_body": "بروزرسانی های شیرین و کوتاه موزیلا در مورد فایرفاکس،‌ فرهنگ اینترنت، و تصاویر تصادفی مناسبتی مطالعه کنید.",
  "settings_pane_done_button": "انجام شد",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "ويرايش",
  "edit_topsites_button_label": "قسمت سایت‌های برتر را سفارشی کنید",
  "edit_topsites_showmore_button": "نمایش بیشتر",
  "edit_topsites_showless_button": "نمایش کمتر",
  "edit_topsites_done_button": "انجام شد",
  "edit_topsites_pin_button": "چسباندن این سایت",
  "edit_topsites_unpin_button": "لغو سنجاق کردن این پایگاه اینترنتی",
  "edit_topsites_edit_button": "ویرایش این سایت",
  "edit_topsites_dismiss_button": "نادیده گرفتن این سایت",
  "edit_topsites_add_button": "افزودن",
  "topsites_form_add_header": "سایت برتر جدید",
  "topsites_form_edit_header": "ویرایش سایت برتر",
  "topsites_form_title_placeholder": "عنوان را وارد کنید",
  "topsites_form_url_placeholder": "یک URL تایپ کنید یا بچسبانید",
  "topsites_form_add_button": "افزودن",
  "topsites_form_save_button": "ذخیره",
  "topsites_form_cancel_button": "انصراف",
  "topsites_form_url_validation": "URL معتبر الزامی است",
  "pocket_read_more": "موضوع‌های محبوب:",
  "pocket_read_even_more": "مشاهده داستان‌های بیشتر",
  "pocket_feedback_header": "بهترین‌های وب، گزینش شده توسط بیش از ۲۵ میلیون نفر.",
  "pocket_description": "محتواهای با کیفیتی را پیدا کنید که ممکن است از دست داده باشید، به کمک Pocket که اکنون بخشی از موزیلا است.",
  "highlights_empty_state": "مرور کردن را شروع کنید و شاهد تعداد زیادی مقاله، فیلم و صفحات خوبی باشید که اخیر مشاهده کرده اید یا نشانگ گذاری کرده اید.",
  "topstories_empty_state": "فعلا تموم شد. بعدا دوباره سر بزن تا مطالب جدید از {provider} ببینی. نمی‌تونی صبر کنی؟ یک موضوع محبوب رو انتخاب کن تا مطالب جالب مرتبط از سراسر دنیا رو پیدا کنی.",
  "manual_migration_explanation2": "فایرفاکس را با نشانک‌ها،‌ تاریخچه‌ها و کلمات عبور از سایر مرورگر ها تجربه کنید.",
  "manual_migration_cancel_button": "نه ممنون",
  "manual_migration_import_button": "هم‌اکنون وارد شوند"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/fa/activity-stream-strings.js <==
// Note - this is a generated fa file.
window.gActivityStreamStrings = {
  "newtab_page_title": "زبانه جدید",
  "header_top_sites": "سایت‌های برتر",
  "header_highlights": "برجسته‌ها",
  "header_recommended_by": "پیشنهاد شده توسط {provider}",
  "context_menu_button_sr": "بازکردن فهرست زمینه برای {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "مشاهده شده",
  "type_label_bookmarked": "نشانک شده",
  "type_label_recommended": "موضوعات داغ",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "نشانک",
  "menu_action_remove_bookmark": "حذف نشانک",
  "menu_action_open_new_window": "باز کردن در یک پنجره جدید",
  "menu_action_open_private_window": "بار کردن در یک پنجره ناشناس جدید",
  "menu_action_dismiss": "رد کردن",
  "menu_action_delete": "حذف از تاریخچه",
  "menu_action_pin": "سنجاق کردن",
  "menu_action_unpin": "جدا کردن",
  "confirm_history_delete_p1": "آیا از پاک کردن همه نمونه‌های این صفحه از تاریخ‌چه خود اطمینان دارید؟",
  "confirm_history_delete_notice_p2": "این عمل قابل برگشت نیست.",
  "menu_action_save_to_pocket": "ذخیره‌سازی در Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "جست‌وجو",
  "search_header": "جست‌وجو {search_engine_name}",
  "search_web_placeholder": "جست‌وجوی وب",
  "section_disclaimer_topstories": "جالب‌ترین داستان‌ها در وب، بر اساس آنچه شما خواندید انتخاب شده است. از Pocket، که حالا بخشی از Mozilla است.",
  "section_disclaimer_topstories_linktext": "ببینید چگونه کار می‌کند.",
  "section_disclaimer_topstories_buttontext": "باشه، گرفتم",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "صفحهٔ زبانه جدید را سفارشی کنید",
  "settings_pane_topsites_header": "سایت‌های برتر",
  "settings_pane_highlights_header": "برجسته‌ها",
  "settings_pane_highlights_options_bookmarks": "نشانک‌ها",
  "settings_pane_snippets_header": "قطعه‌ها",
  "edit_topsites_button_text": "ويرايش",
  "edit_topsites_edit_button": "ویرایش این سایت",
  "topsites_form_add_header": "سایت برتر جدید",
  "topsites_form_edit_header": "ویرایش سایت برتر",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "عنوان را وارد کنید",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "یک URL تایپ کنید یا بچسبانید",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "افزودن",
  "topsites_form_save_button": "ذخیره",
  "topsites_form_cancel_button": "انصراف",
  "topsites_form_url_validation": "URL معتبر الزامی است",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "موضوع‌های محبوب:",
  "pocket_read_even_more": "مشاهده داستان‌های بیشتر",
  "highlights_empty_state": "مرور کردن را شروع کنید و شاهد تعداد زیادی مقاله، فیلم و صفحات خوبی باشید که اخیر مشاهده کرده اید یا نشانگ گذاری کرده اید.",
  "topstories_empty_state": "فعلا تموم شد. بعدا دوباره سر بزن تا مطالب جدید از {provider} ببینی. نمی‌تونی صبر کنی؟ یک موضوع محبوب رو انتخاب کن تا مطالب جالب مرتبط از سراسر دنیا رو پیدا کنی.",
  "manual_migration_explanation2": "فایرفاکس را با نشانک‌ها،‌ تاریخچه‌ها و کلمات عبور از سایر مرورگر ها تجربه کنید.",
  "manual_migration_cancel_button": "نه ممنون",
  "manual_migration_import_button": "هم‌اکنون وارد شوند",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "در حال بارگیری…",
  "header_stories": "برترین داستان‌ها",
  "header_visit_again": "مشاهده دوباره",
  "header_bookmarks": "نشانک‌های اخیر",
  "header_bookmarks_placeholder": "هنوز هیچ نشانکی ندارید.",
  "header_stories_from": "از",
  "type_label_synced": "هم‌گام شده از دستگاهی دیگر",
  "type_label_open": "باز کردن",
  "type_label_topic": "موضوع",
  "type_label_now": "هم‌اکنون",
  "menu_action_copy_address": "رونوشت از آدرس",
  "menu_action_email_link": "ارسال پیوند…",
  "search_for_something_with": "جست‌وجو برای {search_term} با:",
  "search_settings": "تغییر تنظیمات جست‌وجو",
  "section_info_option": "اطلاعات",
  "section_info_send_feedback": "ارسال بازخورد",
  "section_info_privacy_notice": "نکات حفظ حریم خصوصی",
  "welcome_title": "به زبانه جدید خوش‌آمدید",
  "welcome_body": "فایرفاکس از این فضا برای نمایش نشانک‌ها، مقالات، ویدئوها و صفحات مرتبطی که به‌تازگی مشاهده کرده‌اید استفاده می‌کند، تا شما به راحتی دوباره به آنها دسترسی داشته باشید.",
  "welcome_label": "شناسایی گزینه‌های برجسته شما",
  "time_label_less_than_minute": "> ۱ دقیقه",
  "time_label_minute": "{number} د",
  "time_label_hour": "{number} س",
  "time_label_day": "{number} ر",
  "settings_pane_header": "تنظیمات زبانه جدید",
  "settings_pane_body2": "انتخاب کنید چیزی را که مایل هستید در این صفحه مشاهده کنید.",
  "settings_pane_search_header": "جست‌وجو",
  "settings_pane_search_body": "وب را از زبانه جدید خود جست‌وجو کنید.",
  "settings_pane_topsites_body": "به وب‌سایت‌هایی که بیشترین بازدید از آنها را داشتید دسترسی داشته باشید.",
  "settings_pane_topsites_options_showmore": "نمایش دو ردیفی",
  "settings_pane_bookmarks_header": "نشانک‌های اخیر",
  "settings_pane_bookmarks_body": "به‌تازگی شما نشانک‌هایی را در یک محل مناسب ساخته‌اید.",
  "settings_pane_visit_again_header": "مشاهده دوباره",
  "settings_pane_visit_again_body": "فایرفاکس بخش‌هایی از تاریخ‌چه مرورتان را که ممکن است بخواهید به یاد داشته باشید یا به آن‌ها بازگردید به شما نشان خواهد داد.",
  "settings_pane_highlights_body2": "راه خود را در میان چیزهایی که دوست دارید پیدا کنید.چیزهایی که اخیرا مشاهده کرده اید یا نشانک ها.",
  "settings_pane_highlights_options_visited": "سایت‌های بازدید شده",
  "settings_pane_snippets_body": "بروزرسانی های شیرین و کوتاه موزیلا در مورد فایرفاکس،‌ فرهنگ اینترنت، و تصاویر تصادفی مناسبتی مطالعه کنید.",
  "settings_pane_done_button": "انجام شد",
  "settings_pane_topstories_options_sponsored": "نمایش داستان‌های حمایت شده",
  "edit_topsites_button_label": "قسمت سایت‌های برتر را سفارشی کنید",
  "edit_topsites_showmore_button": "نمایش بیشتر",
  "edit_topsites_showless_button": "نمایش کمتر",
  "edit_topsites_done_button": "انجام شد",
  "edit_topsites_pin_button": "چسباندن این سایت",
  "edit_topsites_unpin_button": "لغو سنجاق کردن این پایگاه اینترنتی",
  "edit_topsites_dismiss_button": "نادیده گرفتن این سایت",
  "edit_topsites_add_button": "افزودن",
  "edit_topsites_add_button_tooltip": "اضافه کردن به سایت های برتر",
  "pocket_feedback_header": "بهترین‌های وب، گزینش شده توسط بیش از ۲۵ میلیون نفر.",
  "pocket_description": "محتواهای با کیفیتی را پیدا کنید که ممکن است از دست داده باشید، به کمک Pocket که اکنون بخشی از موزیلا است."
};
